;********************************************************************************************
;* Title:  PWM_ATD.ASM                      (c) MOTOROLA Inc. 2003 All rights reserved.
;********************************************************************************************
;* Author: Bill Lucas - Motorola TSPG
;*
;* Description: Pulsed width modulation and analog to digital converter demo
;*
;* This program will modulate the brightness of an LED by a PWM output,based off of an
;* analog input. The analog input is the result of an integrator, driven from another
;* PWM output. The duty cycle of PWM output, driving the integrator is ramped
;* from 0% to 100% and back to 0% by depressing SW1 and SW2 on the demp PC board.
;*
;* Documentation: 9S08GB60 family Data Sheet and HCS08 Family Reference Manual (HCS08RM1/D)
;*
;* Include Files: None
;*
;* Assembler:  Metrowerks Code Warrior 3.0 (pre-release)
;*             or P&E Microcomputer Systems - CASMS08 (beta v4.02)
;*
;* Revision History:  not yet released
;* Rev #     Date       Who     Comments
;* -----  -----------  ------  --------------------------------------------
;*  1.2    25-Apr-03   B.Lucas  Correct minor typos in comments
;*  1.1    21-Apr-03   B.Lucas  Comments and modify for CW 3.0 project
;*  1.0    04-Apr-03   B.Lucas  Initial code release
;********************************************************************************************
             base  10t         ;change default to decimal

;
;* Initialize the analog to digital converter for continuous
;* 8-bit conversions on channel 1.
;
Init_adt     equ    *
             mov    #mATDPE1,ATDPE	;enable channel 1
             mov    #(mATDPU|mRES8|mPRS3|mPRS2|mPRS1|mPRS0),ATDC
             mov    #(mATDCO|ATDCH1),ATDSC ;continuous convert ch #1
             rts
;
;* Initialize TPM1 channels 0 and 2 for PWM output using a bus clock
;* of 1.05 MHz
;
Timer_init   equ    *
             mov    #(mCLKSA|mPS2),TPM1SC ;Select bus clock and /16
             mov    #0,TPM1MODH
             mov    #$ff,TPM1MODL ;4.607 kHz base freq.
             mov    #(mMS1B|mELS1A),TPM1C0SC ;edge PWM, low true
             mov    #(mMS2B|mELS1B),TPM1C2SC ;edge PWM, high true
             mov    #$0,TPM1C0VH  ;set both PWM's at 50% duty cycle
             mov    #$0,TPM1C2VH  ;
             mov    #$80,TPM1C0VL ;
             mov    #$80,TPM1C2VL ;now output 50% to both PWM's
             rts
;
PWM_ATD      mov    #(mPTAPE5|mPTAPE4),PTAPE
             bsr    Timer_init    ;initialize both timer channels
             bsr    Init_adt      ;initialize the A/D converter
             lda    TPM1SC        ;dummy read to clear timer flag
             bset   TOF,TPM1SC    ;second half of clearing
timer_loop   brclr  TOF,TPM1SC,timer_loop ;hang here until overflow
             lda    TPM1SC        ;clear timer overflow flag
             bclr   TOF,TPM1SC    ;second half of clearing
;
             ldx    ATDRH         ;get the analog from integrator
             clrh                 ;write 16 bits to timer val reg
             sthx   TPM1C0VH      ;update PWM to the LED
;
             lda    delay_cntr    ;bump the delay counter
             inca
             sta    delay_cntr    ;bumped
             cmp    #50           ;been here 50 times yet?
             bne    timer_loop    ;no
;
             mov    #0,delay_cntr ;yes..reset counter
             lda    PTAD          ;loop until a key is pressed
             and    #(mPTAD5|mPTAD4)
             cmp    #(mPTAD5|mPTAD4)
             beq    timer_loop    ;no key is pressed
;	
             brclr  PTAD4,PTAD,decrement ;decrement PWM duty cycle
             lda    TPM1C2VL      ;else increment the PWM duty cycle
             cmp    #$fe
             beq    timer_loop    ;ignore it as hi as we want to go
             ldhx   TPM1C2VH      ;increase the PWM to the integrator
             aix    #1
             bra    write_low     ;write low byte and continue
decrement    lda    TPM1C2VL
             cmp    #1
             beq    timer_loop    ;ignore it as low as we want to go
             ldhx   TPM1C2VH      ;decrease the PWM to the integrator
             aix    #-1
write_low    sthx   TPM1C2VH
             bra    timer_loop    ;continue
