;********************************************************************************************
;* Title:  RTI_DEMO.ASM                      (c) MOTOROLA Inc. 2003 All rights reserved.
;********************************************************************************************
;* Author: Bill Lucas - Motorola TSPG
;*
;* Description: Real time interrupt/stop recovery demo
;*
;* This demo demonstrates the GB60 operating in low power stop3 mode. The Real Time
;* Interrupt is used to wake-up the CPU every 0.512 seconds. When the CPU wakes-up,
;* LED1 is blinked on and offf very quickly, to indicare activity. In stop3 mode,
;* the Real Time interrupt issues and interruptto the CPU to recover from stop3 mode.
;
;* Documentation: 9S08GB60 family Data Sheet and HCS08 Family Reference Manual (HCS08RM1/D)
;*
;* Include Files: None
;*
;* Assembler:  Metrowerks Code Warrior 3.0 (pre-release)
;*             or P&E Microcomputer Systems - CASMS08 (beta v4.02)
;*
;* Revision History:  not yet released
;* Rev #     Date       Who     Comments
;* -----  -----------  ------  --------------------------------------------
;*  1.2    25-Apr-03   B.Lucas  Correct minor typos in comments
;*  1.1    21-Apr-03   B.Lucas  Comments and modify for CW 3.0 project
;*  1.0    04-Apr-03   B.Lucas  Initial code release
;********************************************************************************************

RTI_DEMO     equ    *
             lda    SRTISC        ;dummy acknowlege RTI interrupt
             ora    #mRTIACK
             sta    SRTISC        ;done
             stop                 ;wait for the first RTI

RTI_DEMO1    equ    *
             lda    SPMSC1
             eor    #mLVDSE
             sta    SPMSC1       ;enable lvd during stop
	
sw_chk	brset SW1,SWITCH_PORT,look_sw2 ;is SW1 depressed?
             mov    #timer_led,rti_cnt1 ;yes

look_sw2     brset  SW2,SWITCH_PORT,look_sw3 ;is SW2 depressed?
             mov    #timer_led,rti_cnt2 ;yes

look_sw3     brset  SW3,SWITCH_PORT,look_sw4 ;is SW3 depressed?
             mov    #timer_led,rti_cnt3 ;yes

look_sw4     brset  SW4,SWITCH_PORT,tst_timer ;is SW4 depressed?
             mov    #timer_led,rti_cnt4 ;yes
	
tst_timer    lda    rti_cnt1      ;get count and if > 0 turn on LED
             beq    rti_cnt1_0    ;is the count = 0
             deca                 ;no
             sta    rti_cnt1      ;bump counter down
             bclr   LED1,PTFD     ;turn on LED1
             bra    rti_cnt1_1    ;is the count > 0
rti_cnt1_0   bset   LED1,PTFD     ;turn off LED1
	
rti_cnt1_1   lda    rti_cnt2      ;get count and if > 0 turn on LED
             beq    rti_cnt2_0    ;is the count = 0
             deca                 ;no
             sta    rti_cnt2      ;bump counter down
             bclr   LED2,PTFD     ;turn on LED2
             bra    rti_cnt2_1    ;is the count > 0
rti_cnt2_0   bset   LED2,PTFD     ;turn off LED2

rti_cnt2_1   lda    rti_cnt3      ;get count and if > 0 turn on LED
             beq    rti_cnt3_0    ;is the count = 0
             deca                 ;no
             sta    rti_cnt3      ;bump counter down
             bclr   LED3,PTFD     ;turn on LED3
             bra    rti_cnt3_1    ;is the count > 0
rti_cnt3_0   bset   LED3,PTFD     ;turn off LED3

rti_cnt3_1   lda    rti_cnt4      ;get count and if > 0 turn on LED
             beq    rti_cnt4_0    ;is the count = 0
             deca                 ;no
             sta    rti_cnt4      ;bump counter down
             bclr   LED4,PTFD     ;turn on LED4
             bra    led1_chk      ;is the count > 0
rti_cnt4_0   bset   LED4,PTFD     ;turn off LED4

led1_chk     lda    rti_cnt1      ;if rti_cnt1 = 0, fast blink LED1
             bne    stop
	
none_pushed  bclr   LED,PTFD      ;turn on LED
             clra                 ;leave it on for a short time
onloop       deca
             brn    *             ;burn some extra cycles
             brn    *
             brn    *
             bne    onloop        ;delay over yet?
             bset   LED,PTFD      ;yes..turn LED off
	
stop         equ    *

             stop                 ;spend most of our time here
             bra    RTI_DEMO1

clear_cnt    equ    *             ;Called at reset
             clr    rti_cnt1      ;initialize on LED1 delay time
             clr    rti_cnt2      ;initialize on LED2 delay time
             clr    rti_cnt3      ;initialize on LED3 delay time
             clr    rti_cnt4      ;initialize on LED4 delay time
             rts

rti_isr      lda    SRTISC        ;acknowlege RTI interrupt
             ora    #mRTIACK
             sta    SRTISC        ;done
             rti

